/*
 *      vdr-plugin-robotv - roboTV server plugin for VDR
 *
 *      Copyright (C) 2016 Alexander Pipelka
 *
 *      https://github.com/pipelka/vdr-plugin-robotv
 *
 *  This Program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This Program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *  http://www.gnu.org/copyleft/gpl.html
 *
 */

#ifndef ROBOTV_CLIENT_H
#define ROBOTV_CLIENT_H

#include <list>
#include <string>
#include <deque>
#include <map>
#include <thread>

#include <vdr/tools.h>
#include <vdr/receiver.h>
#include <vdr/status.h>

#include "robotvdmx/streaminfo.h"
#include "net/msgpacket.h"
#include "recordings/artwork.h"

#include "controllers/streamcontroller.h"
#include "controllers/recordingcontroller.h"
#include "controllers/channelcontroller.h"
#include "controllers/timercontroller.h"
#include "controllers/moviecontroller.h"
#include "controllers/logincontroller.h"
#include "controllers/epgcontroller.h"
#include "controllers/artworkcontroller.h"

class cChannel;
class cDevice;
class PacketPlayer;

class RoboTvClient : public cThread, public cStatus {
private:

    unsigned int m_id;

    int m_socket;

    MsgPacket* m_request = NULL;

    Utf8Conv m_toUtf8;

    int m_timeout = 3000;

    std::deque<MsgPacket*> m_queue;

    std::mutex m_queueLock;

    // Controllers

    StreamController m_streamController;

    RecordingController m_recordingController;

    ChannelController m_channelController;

    TimerController m_timerController;

    MovieController m_movieController;

    LoginController m_loginController;

    EpgController m_epgController;

    ArtworkController m_artworkController;

    std::list<Controller*> m_controllers;

protected:

    bool processRequest();

    virtual void Action(void);

    virtual void Recording(const cDevice* Device, const char* Name, const char* FileName, bool On);
    virtual void TimerChange(const cTimer* Timer, eTimerChange Change);
    virtual void ChannelChange(const cChannel* Channel);

public:

    RoboTvClient(int fd, unsigned int id);

    virtual ~RoboTvClient();

    void onRecording(const cEvent* event, bool on);

    void queueMessage(MsgPacket* p);

    void broadcastMessage(MsgPacket* p);

    void sendStatusMessage(const char* Message);

    unsigned int getId() const {
        return m_id;
    }

    int getSocket() const {
        return m_socket;
    }
};

#endif // ROBOTV_CLIENT_H
